<?php

namespace XenGenTr\ResimliOneCikanKonular;

use XF\AddOn\AbstractSetup;
use XF\AddOn\StepRunnerInstallTrait;
use XF\AddOn\StepRunnerUninstallTrait;
use XF\AddOn\StepRunnerUpgradeTrait;
use XF\Db\Schema\Alter;
use XF\Db\Schema\Create;

class Setup extends AbstractSetup
{
	use StepRunnerInstallTrait;
	use StepRunnerUpgradeTrait;
	use StepRunnerUninstallTrait;

    /**
     * ----------------
     *     Kuruluma bala
     * ----------------
     */

	public function installStep1()
	{
        $schemaManager = $this->schemaManager();

        foreach ($this->getTables() AS $tableName => $closure)
        {
            $schemaManager->createTable($tableName, $closure);
        }

        $this->createWidget('xgt_onecikan_konular', 'xgtOnecikanKonular_wd', [
            'positions' => []

        ]);

	}

	public function installStep2()
	{
		$target = \XF::getRootDirectory().'/data/XenGenTr';
		if (!is_dir($target)) { mkdir($target, 0777); }
	}
	
	public function installStep3()
	{
		$target = \XF::getRootDirectory().'/data/XenGenTr/xengentr_resimlikonular';
		if (!is_dir($target)) { mkdir($target, 0777); }
	}


	public function upgrade2010030Step1()
	{
		$sm = $this->schemaManager();

		$renameTables = [
			'xengentr_resimlionecikanlar' => 'xgt_onecikan_konular',
		];

		foreach ($renameTables AS $from => $to)
		{
			$sm->renameTable($from, $to);
		}

    }

	public function upgrade2010030Step2()
	{
		$sm = $this->schemaManager();

		$sm->alterTable('xgt_onecikan_konular', function(Alter $table)
		{
			$table->renameColumn('resimlionecikan_tarih', 'onecikan_tarih');
			$table->renameColumn('resimlionecikan_saat', 'onecikan_zaman');
			$table->renameColumn('resimlionecikan_baslik', 'onecikan_baslik');
            $table->renameColumn('resimlionecikan_icerik', 'onecikan_aciklama');
		});

    }

	public function upgrade2010030Step3()
	{
	
		$target = glob(\XF::getRootDirectory().'/src/addons/XenGenTr/ResimliOneCikanKonular/Entity/ResimliOnecikan.php');
		foreach ($target AS $file) { unlink($file); }

	    $target = glob(\XF::getRootDirectory().'/src/addons/XenGenTr/ResimliOneCikanKonular/Finder/ResimliOnecikan.php');
		foreach ($target AS $file) { unlink($file); }

        $target = glob(\XF::getRootDirectory().'/src/addons/XenGenTr/ResimliOneCikanKonular/Repository/ResimliOnecikan.php');
		foreach ($target AS $file) { unlink($file); }
	
        $target = glob(\XF::getRootDirectory().'/src/addons/XenGenTr/ResimliOneCikanKonular/Service/YardimDetay.php');
		foreach ($target AS $file) { unlink($file); }

        $target = glob(\XF::getRootDirectory().'/src/addons/XenGenTr/ResimliOneCikanKonular/Widget/ResimliOnecikanlar.php');
		foreach ($target AS $file) { unlink($file); }
	}

	public function upgrade3000600Step1()
	{
        $this->deleteWidget('ResimliOneCikanWidget');

        $this->createWidget('xgt_onecikan_konular', 'xgtOnecikanKonular_wd', [
            'positions' => []

        ]);
	}

	public function uninstallStep1()
	{
		$this->schemaManager()->dropTable(
                   'xgt_onecikan_konular'
        );
	}

	public function uninstallStep2()
	{
	
		$target = glob(\XF::getRootDirectory().'/data/XenGenTr/xengentr_resimlikonular/*.jpg');
		foreach ($target AS $file) { unlink($file); }

		$target = \XF::getRootDirectory().'/data/XenGenTr/xengentr_resimlikonular';
		if (is_dir($target)) { rmdir($target); }
	}


    public function uninstallStep3()
    {
        $this->deleteWidget('xgtOnecikanKonular_wd');
    }


	protected function applyDefaultPermissions($previousVersion = null)
	{
		$applied = false;

		if (!$previousVersion || $previousVersion < 2010010)
		{

           $this->applyGlobalPermission('ResimliKonular_izinler', 'resimlionecikan_gor', 'general', 'viewNode');

		   $applied = true;
		}

		return $applied;
	}


    protected function getTables()
    {
        $tables = [];

        $tables['xgt_onecikan_konular'] = function (Create $table)
        {
               $table->checkExists(true);
		       $table->addColumn('thread_id', 		 'int', 10);
			   $table->addColumn('onecikan_tarih',	 'int', 10);
			   $table->addColumn('onecikan_zaman',	 'int', 10);
			   $table->addColumn('onecikan_baslik',  'varchar', 255);
			   $table->addColumn('onecikan_aciklama', 'text');
			   $table->addPrimaryKey('thread_id');
        };

        return $tables;
	}

	protected function getData()
	{
		$data = new MySql();

		return $data->getData();
	}
}